@@ -1,11 +1,14 @@
 package Regex::Object::Matches;
 
 use 5.20.0;
-use strict;
-use warnings qw(FATAL);
+
 use utf8;
+use English;
+use feature qw(signatures);
 
 use Moo;
+
+no warnings qw(experimental::signatures);
 use namespace::clean;
 
 has collection => (
@@ -17,18 +20,15 @@ has count => (
     is => 'rwp',
 );
 
-sub BUILD {
-    my $self = shift;
+sub BUILD($self, $args) {
     $self->_set_count(scalar @{$self->collection});
 }
 
-sub match_all {
-    my $self = shift;
+sub match_all($self) {
     return [map { $_->match } @{$self->collection}];
 }
 
-sub captures_all {
-    my $self = shift;
+sub captures_all($self) {
     return [map { $_->captures } @{$self->collection}];
 }
 
